/* file: ./contracts/ERC820aImplementerInterface.sol */
pragma solidity ^0.4.24;


contract ERC820aImplementerInterface {
    bytes32 constant ERC820a_ACCEPT_MAGIC = keccak256(abi.encodePacked("ERC820a_ACCEPT_MAGIC"));

    /// @notice Indicates whether the contract implements the interface `interfaceHash` for the address `addr`.
    /// @param interfaceHash keccak256 hash of the name of the interface
    /// @param addr Address for which the contract will implement the interface
    /// @return ERC820a_ACCEPT_MAGIC only if the contract implements `ìnterfaceHash` for the address `addr`.
    function canImplementInterfaceForAddress(bytes32 interfaceHash, address addr) external view returns(bytes32);
}

/* eof (./contracts/ERC820aImplementerInterface.sol) */
/* file: ./contracts/ExampleImplementer.sol */
pragma solidity ^0.4.24;



contract ExampleImplementer is ERC820aImplementerInterface {
    function canImplementInterfaceForAddress(bytes32 interfaceHash, address addr) external view returns(bytes32) {
        return ERC820a_ACCEPT_MAGIC;
    }
}

/* eof (./contracts/ExampleImplementer.sol) */
